==> fantasy-0.6.8+1.21.9-sources.jar: xyz/nucleoid/fantasy/util/TransientChunkGenerator.java <==
package xyz.nucleoid.fantasy.util;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.registry.RegistryOps;
import net.minecraft.registry.entry.RegistryEntry;
import net.minecraft.world.biome.Biome;
import net.minecraft.world.biome.BiomeKeys;
import net.minecraft.world.biome.GenerationSettings;
import net.minecraft.world.biome.source.BiomeSource;
import net.minecraft.world.gen.chunk.ChunkGenerator;
import xyz.nucleoid.fantasy.RuntimeWorldConfig;

import java.util.function.Function;

/**
 * A {@link ChunkGenerator} instance that does not know how to be, and does not care to be serialized.
 * This is particularly useful when creating a temporary world with Fantasy.
 * <p>
 * If serialized, however, it will be loaded as a {@link VoidChunkGenerator void world}.
 *
 * @see xyz.nucleoid.fantasy.Fantasy#openTemporaryWorld(RuntimeWorldConfig)
 */
public abstract class TransientChunkGenerator extends ChunkGenerator {
    public static final MapCodec<? extends ChunkGenerator> CODEC = RecordCodecBuilder.mapCodec(i -> i.group(
            RegistryOps.getEntryCodec(BiomeKeys.THE_VOID)
    ).apply(i, VoidChunkGenerator::new));

    public TransientChunkGenerator(BiomeSource biomeSource) {
        super(biomeSource);
    }

    public TransientChunkGenerator(BiomeSource biomeSource, Function<RegistryEntry<Biome>, GenerationSettings> generationSettingsGetter) {
        super(biomeSource, generationSettingsGetter);
    }

    @Override
    protected final MapCodec<? extends ChunkGenerator> getCodec() {
        return CODEC;
    }
}

==> fantasy-0.7.0+1.21.11-sources.jar: xyz/nucleoid/fantasy/util/TransientChunkGenerator.java <==
package xyz.nucleoid.fantasy.util;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import xyz.nucleoid.fantasy.RuntimeWorldConfig;

import java.util.function.Function;
import net.minecraft.core.Holder;
import net.minecraft.resources.RegistryOps;
import net.minecraft.world.level.biome.Biome;
import net.minecraft.world.level.biome.BiomeGenerationSettings;
import net.minecraft.world.level.biome.BiomeSource;
import net.minecraft.world.level.biome.Biomes;
import net.minecraft.world.level.chunk.ChunkGenerator;

/**
 * A {@link ChunkGenerator} instance that does not know how to be, and does not care to be serialized.
 * This is particularly useful when creating a temporary world with Fantasy.
 * <p>
 * If serialized, however, it will be loaded as a {@link VoidChunkGenerator void world}.
 *
 * @see xyz.nucleoid.fantasy.Fantasy#openTemporaryWorld(RuntimeWorldConfig)
 */
public abstract class TransientChunkGenerator extends ChunkGenerator {
    public static final MapCodec<? extends ChunkGenerator> CODEC = RecordCodecBuilder.mapCodec(i -> i.group(
            RegistryOps.retrieveElement(Biomes.THE_VOID)
    ).apply(i, VoidChunkGenerator::new));

    public TransientChunkGenerator(BiomeSource biomeSource) {
        super(biomeSource);
    }

    public TransientChunkGenerator(BiomeSource biomeSource, Function<Holder<Biome>, BiomeGenerationSettings> generationSettingsGetter) {
        super(biomeSource, generationSettingsGetter);
    }

    @Override
    protected final MapCodec<? extends ChunkGenerator> codec() {
        return CODEC;
    }
}
